@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -78,7 +78,7 @@ ASActivity::ASActivity(QVariantMap activityMap, QString userId,
 
     // Audience: To
     QVariantMap aToMap;
-    foreach (QVariant toVariant, activityMap.value("to").toList())
+    foreach (const QVariant toVariant, activityMap.value("to").toList())
     {
         aToMap = toVariant.toMap();
 
@@ -125,7 +125,7 @@ ASActivity::ASActivity(QVariantMap activityMap, QString userId,
 
     // and Cc
     QVariantMap aCcMap;
-    foreach (QVariant ccVariant, activityMap.value("cc").toList())
+    foreach (const QVariant ccVariant, activityMap.value("cc").toList())
     {
         aCcMap = ccVariant.toMap();
 
