@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -553,7 +553,7 @@ QString ASObject::personStringFromList(QVariantList variantList, int count)
 {
     QString personString;
 
-    foreach (QVariant listItem, variantList)
+    foreach (const QVariant listItem, variantList)
     {
         QVariantMap itemMap = listItem.toMap();
 
@@ -633,12 +633,12 @@ QString ASObject::personStringFromSimpleMap(QVariantMap personMap,
 {
     QString personString;
 
-    foreach (QString key, personMap.keys())
+    foreach (const QString key, personMap.keys())
     {
         personString.append(personMap.value(key).toString() + ", ");
     }
 
-    int remainingCount = totalCount - personMap.keys().length();
+    const int remainingCount = totalCount - personMap.keys().length();
 
     // Add "and $COUNT other"
     if (remainingCount > 0)
