@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
                                    QString selectorType,
                                    QWidget *parent) : QFrame(parent)
 {
-    this->selectorType = selectorType;
-    this->m_pumpController = pumpController;
+    m_selectorType = selectorType;
+    m_pumpController = pumpController;
 
     QString titlePart;
-    if (this->selectorType == "to")
+    if (m_selectorType == QStringLiteral("to"))
     {
         titlePart = tr("'To' List");
     }
@@ -55,110 +55,109 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
 
 
     // Upper-left side, all contacts, with filter
-    this->peopleWidget = new PeopleWidget(tr("&Add to Selected") + " >>",
-                                          PeopleWidget::EmbeddedWidget,
-                                          m_pumpController,
+    m_peopleWidget = new PeopleWidget(tr("&Add to Selected") + " >>",
+                                      PeopleWidget::EmbeddedWidget,
+                                      m_pumpController,
+                                      this);
+    connect(m_peopleWidget, &PeopleWidget::contactSelected,
+            this, &AudienceSelector::copyToSelected);
+    connect(m_peopleWidget, &PeopleWidget::addButtonPressed,
+            this, &AudienceSelector::copyToSelected);
+
+
+
+    m_allGroupboxLayout = new QVBoxLayout();
+    m_allGroupboxLayout->setContentsMargins(0, 0, 0, 0);
+    m_allGroupboxLayout->addWidget(m_peopleWidget);
+
+    m_allContactsGroupbox = new QGroupBox(tr("All Contacts"),
                                           this);
-    connect(peopleWidget, &PeopleWidget::contactSelected,
-            this, &AudienceSelector::copyToSelected);
-    connect(peopleWidget, &PeopleWidget::addButtonPressed,
-            this, &AudienceSelector::copyToSelected);
-
-
-
-    this->allGroupboxLayout = new QVBoxLayout();
-    allGroupboxLayout->setContentsMargins(0, 0, 0, 0);
-    allGroupboxLayout->addWidget(peopleWidget);
-
-    allContactsGroupbox = new QGroupBox(tr("All Contacts"),
-                                        this);
-    allContactsGroupbox->setLayout(allGroupboxLayout);
+    m_allContactsGroupbox->setLayout(m_allGroupboxLayout);
 
 
     // Upper-right side, selected contacts
-    explanationLabel = new QLabel(tr("Select people from the list on the left.\n"
-                                     "You can drag them with the mouse, click or "
-                                     "double-click on them, or select them and "
-                                     "use the button below.",
-                                     "ON THE LEFT should change to ON THE "
-                                     "RIGHT in RTL languages"),
-                                  this);
-    explanationLabel->setWordWrap(true);
+    m_explanationLabel = new QLabel(tr("Select people from the list on the left.\n"
+                                       "You can drag them with the mouse, click or "
+                                       "double-click on them, or select them and "
+                                       "use the button below.",
+                                       "ON THE LEFT should change to ON THE "
+                                       "RIGHT in RTL languages"),
+                                    this);
+    m_explanationLabel->setWordWrap(true);
 
-    selectedListWidget = new QListWidget(this);
-    selectedListWidget->setDragDropMode(QListView::DragDrop);
-    selectedListWidget->setDefaultDropAction(Qt::MoveAction);
-    selectedListWidget->setSelectionMode(QListView::ExtendedSelection);
-    selectedListWidget->setIconSize(QSize(48, 48));
+    m_selectedListWidget = new QListWidget(this);
+    m_selectedListWidget->setDragDropMode(QListView::DragDrop);
+    m_selectedListWidget->setDefaultDropAction(Qt::MoveAction);
+    m_selectedListWidget->setSelectionMode(QListView::ExtendedSelection);
+    m_selectedListWidget->setIconSize(QSize(48, 48));
 
-    this->clearSelectedListButton = new QPushButton(QIcon::fromTheme("edit-clear-list",
-                                                                     QIcon(":/images/button-delete.png")),
-                                                    tr("Clear &List"),
-                                                    this);
-    connect(clearSelectedListButton, &QAbstractButton::clicked,
-            selectedListWidget, &QListWidget::clear);
+    m_clearSelectedListButton = new QPushButton(QIcon::fromTheme("edit-clear-list",
+                                                                 QIcon(":/images/button-delete.png")),
+                                                tr("Clear &List"),
+                                                this);
+    connect(m_clearSelectedListButton, &QAbstractButton::clicked,
+            m_selectedListWidget, &QListWidget::clear);
 
 
-    selectedGroupboxLayout = new QVBoxLayout();
-    selectedGroupboxLayout->addWidget(explanationLabel);
-    selectedGroupboxLayout->addSpacing(8);
-    selectedGroupboxLayout->addWidget(selectedListWidget);
-    selectedGroupboxLayout->addWidget(clearSelectedListButton, 0, Qt::AlignLeft);
+    m_selectedGroupboxLayout = new QVBoxLayout();
+    m_selectedGroupboxLayout->addWidget(m_explanationLabel);
+    m_selectedGroupboxLayout->addSpacing(8);
+    m_selectedGroupboxLayout->addWidget(m_selectedListWidget);
+    m_selectedGroupboxLayout->addWidget(m_clearSelectedListButton, 0, Qt::AlignLeft);
 
-    this->selectedListGroupbox = new QGroupBox(tr("Selected People"),
-                                               this);
-    selectedListGroupbox->setLayout(selectedGroupboxLayout);
+    m_selectedListGroupbox = new QGroupBox(tr("Selected People"),
+                                           this);
+    m_selectedListGroupbox->setLayout(m_selectedGroupboxLayout);
 
-    this->upperLayout = new QHBoxLayout();
-    upperLayout->addWidget(allContactsGroupbox,  3);
-    upperLayout->addWidget(selectedListGroupbox, 4);
+    m_upperLayout = new QHBoxLayout();
+    m_upperLayout->addWidget(m_allContactsGroupbox,  3);
+    m_upperLayout->addWidget(m_selectedListGroupbox, 4);
 
 
     // Lower part
-    doneButton = new QPushButton(QIcon::fromTheme("dialog-ok",
-                                                  QIcon(":/images/button-save.png")),
-                                 tr("&Done"),
-                                 this);
-    connect(doneButton, &QAbstractButton::clicked,
+    m_doneButton = new QPushButton(QIcon::fromTheme("dialog-ok",
+                                                    QIcon(":/images/button-save.png")),
+                                   tr("&Done"),
+                                   this);
+    connect(m_doneButton, &QAbstractButton::clicked,
             this, &AudienceSelector::setAudience);
 
-    cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
-                                                    QIcon(":/images/button-cancel.png")),
-                                   tr("&Cancel"),
-                                   this);
-    connect(cancelButton, &QAbstractButton::clicked,
+    m_cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
+                                                      QIcon(":/images/button-cancel.png")),
+                                     tr("&Cancel"),
+                                     this);
+    connect(m_cancelButton, &QAbstractButton::clicked,
             this, &QWidget::close);
 
+    // Group buttons in an environment-aware layout
+    m_bottomButtonBox = new QDialogButtonBox(this);
+    m_bottomButtonBox->addButton(m_doneButton, QDialogButtonBox::AcceptRole);
+    m_bottomButtonBox->addButton(m_cancelButton, QDialogButtonBox::RejectRole);
+
 
     // Layout
-    buttonsLayout = new QHBoxLayout();
-    buttonsLayout->setAlignment(Qt::AlignRight);
-    buttonsLayout->addWidget(doneButton);
-    buttonsLayout->addWidget(cancelButton);
-
-
-    this->mainLayout = new QVBoxLayout();
-    mainLayout->addLayout(upperLayout);
-    mainLayout->addLayout(buttonsLayout);
-    this->setLayout(mainLayout);
+    m_mainLayout = new QVBoxLayout();
+    m_mainLayout->addLayout(m_upperLayout);
+    m_mainLayout->addWidget(m_bottomButtonBox);
+    this->setLayout(m_mainLayout);
 
 
     // Ctrl+Enter is the same as the "Done" button
-    doneAction = new QAction(this);
+    m_doneAction = new QAction(this);
     QList<QKeySequence> doneShortcuts;
     doneShortcuts << QKeySequence("Ctrl+Return")
                   << QKeySequence("Ctrl+Enter");
-    doneAction->setShortcuts(doneShortcuts);
-    connect(doneAction, &QAction::triggered,
+    m_doneAction->setShortcuts(doneShortcuts);
+    connect(m_doneAction, &QAction::triggered,
             this, &AudienceSelector::setAudience);
-    this->addAction(doneAction);
+    this->addAction(m_doneAction);
 
     // ESC is the same as the "Cancel" button
-    cancelAction = new QAction(this);
-    cancelAction->setShortcut(Qt::Key_Escape);
-    connect(cancelAction, &QAction::triggered,
+    m_cancelAction = new QAction(this);
+    m_cancelAction->setShortcut(Qt::Key_Escape);
+    connect(m_cancelAction, &QAction::triggered,
             this, &QWidget::close);
-    this->addAction(cancelAction);
+    this->addAction(m_cancelAction);
 
 
 /////////////////////////////////////////////////////////////////////////////
@@ -206,19 +205,19 @@ AudienceSelector::~AudienceSelector()
  */
 void AudienceSelector::resetLists()
 {
-    this->peopleWidget->resetWidget();
+    m_peopleWidget->resetWidget();
 
-    this->selectedListWidget->clear();
+    m_selectedListWidget->clear();
     restoreSelected();
 }
 
 void AudienceSelector::deletePrevious()
 {
-    foreach (QListWidgetItem *item, previousItems)
+    foreach (QListWidgetItem *item, m_previousItems)
     {
         delete item;
     }
-    previousItems.clear();
+    m_previousItems.clear();
 }
 
 
@@ -228,10 +227,10 @@ void AudienceSelector::saveSelected()
     // Clear and delete all first
     this->deletePrevious();
 
-    int totalItems = this->selectedListWidget->count();
+    const int totalItems = m_selectedListWidget->count();
     for (int counter = 0; counter < totalItems; ++counter)
     {
-        this->previousItems.append(selectedListWidget->item(counter)->clone());
+        m_previousItems.append(m_selectedListWidget->item(counter)->clone());
     }
 }
 
@@ -239,9 +238,9 @@ void AudienceSelector::saveSelected()
 void AudienceSelector::restoreSelected()
 {
     qDebug() << "AudienceSelector::restoreSelected()";
-    foreach (QListWidgetItem *item, this->previousItems)
+    foreach (QListWidgetItem *item, m_previousItems)
     {
-        this->selectedListWidget->addItem(item->clone());
+        m_selectedListWidget->addItem(item->clone());
     }
 }
 
@@ -258,7 +257,7 @@ void AudienceSelector::setDefaultAudience(bool toPublic)
     m_publicAction->setChecked(toPublic);
 
     // Cc: Followers by default
-    m_followersAction->setChecked(this->selectorType == QStringLiteral("cc"));
+    m_followersAction->setChecked(m_selectorType == QStringLiteral("cc"));
 
     // Uncheck the person lists
     foreach (QAction *action, m_listsMenu->actions())
@@ -350,10 +349,10 @@ QString AudienceSelector::updatedAudienceLabels()
 {
     QString audienceString;
 
-    int individualsCount = this->selectedListWidget->count();
+    const int individualsCount = m_selectedListWidget->count();
     for (int counter=0; counter < individualsCount; ++counter)
     {
-        QListWidgetItem *item = selectedListWidget->item(counter);
+        QListWidgetItem *item = m_selectedListWidget->item(counter);
 
         audienceString.append("<a href=\""
                               + item->data(Qt::UserRole + 3).toString()
@@ -442,10 +441,10 @@ QVariantList AudienceSelector::getAudienceList(bool *onlyToFollowers)
     }
 
     // Individual people
-    const int individualsCount = this->selectedListWidget->count();
+    const int individualsCount = m_selectedListWidget->count();
     for (int counter=0; counter < individualsCount; ++counter)
     {
-        QListWidgetItem *item = selectedListWidget->item(counter);
+        QListWidgetItem *item = m_selectedListWidget->item(counter);
 
         audienceItemMap.clear();
         audienceItemMap.insert("objectType", "person");
@@ -479,7 +478,7 @@ QVariantList AudienceSelector::getAudienceList(bool *onlyToFollowers)
 
 int AudienceSelector::getRecipientsCount()
 {
-    return this->selectedListWidget->count();
+    return m_selectedListWidget->count();
 }
 
 
@@ -493,7 +492,7 @@ int AudienceSelector::getRecipientsCount()
 /*
  * Copy a contact to the list of Selected
  *
- * The contact string comes in a SIGNAL from PeopleWidget
+ * The contact string comes in a signal from PeopleWidget
  *
  */
 void AudienceSelector::copyToSelected(QIcon contactIcon, QString contactString,
@@ -502,8 +501,9 @@ void AudienceSelector::copyToSelected(QIcon contactIcon, QString contactString,
 {
     if (!contactString.isEmpty())
     {
-        int itemExists = selectedListWidget->findItems(contactString,
-                                                       Qt::MatchExactly).size();
+        const int itemExists = m_selectedListWidget->findItems(contactString,
+                                                               Qt::MatchExactly)
+                                                    .size();
         if (itemExists == 0)
         {
             QListWidgetItem *item = new QListWidgetItem(contactIcon,
@@ -512,7 +512,7 @@ void AudienceSelector::copyToSelected(QIcon contactIcon, QString contactString,
             item->setData(Qt::UserRole + 2, contactId);
             item->setData(Qt::UserRole + 3, contactUrl);
 
-            this->selectedListWidget->addItem(item);
+            m_selectedListWidget->addItem(item);
         }
         else
         {
@@ -540,7 +540,7 @@ void AudienceSelector::setAudience()
 void AudienceSelector::onListToggled(QAction *listAction)
 {
     qDebug() << "List checked:" << listAction->isChecked()
-             << this->selectorType << listAction->text();
+             << m_selectorType << listAction->text();
 
     emit audienceChanged();
 }
