@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
+#include <QDialogButtonBox>
 #include <QAction>
 #include <QMenu>
 #include <QCloseEvent>
@@ -49,7 +50,7 @@ class AudienceSelector : public QFrame
 public:
     explicit AudienceSelector(PumpController *pumpController,
                               QString selectorType,
-                              QWidget *parent = 0);
+                              QWidget *parent = nullptr);
     ~AudienceSelector();
 
     void resetLists();
@@ -101,30 +102,30 @@ protected:
 
 
 private:
-    QString selectorType;
+    QString m_selectorType;
 
-    QVBoxLayout *mainLayout;
+    QVBoxLayout *m_mainLayout;
 
-    QHBoxLayout *upperLayout;
+    QHBoxLayout *m_upperLayout;
 
-    QVBoxLayout *allGroupboxLayout;
-    QGroupBox *allContactsGroupbox;
+    QVBoxLayout *m_allGroupboxLayout;
+    QGroupBox *m_allContactsGroupbox;
 
-    PeopleWidget *peopleWidget;
+    PeopleWidget *m_peopleWidget;
 
-    QVBoxLayout *selectedGroupboxLayout;
-    QGroupBox *selectedListGroupbox;
+    QVBoxLayout *m_selectedGroupboxLayout;
+    QGroupBox *m_selectedListGroupbox;
 
-    QLabel *explanationLabel;
-    QListWidget *selectedListWidget;
+    QLabel *m_explanationLabel;
+    QListWidget *m_selectedListWidget;
 
-    QList<QListWidgetItem *> previousItems;
+    QList<QListWidgetItem *> m_previousItems;
 
-    QPushButton *clearSelectedListButton;
+    QPushButton *m_clearSelectedListButton;
 
-    QHBoxLayout *buttonsLayout;
-    QPushButton *doneButton;
-    QPushButton *cancelButton;
+    QDialogButtonBox *m_bottomButtonBox;
+    QPushButton *m_doneButton;
+    QPushButton *m_cancelButton;
 
 
     QMenu *m_selectorMenu;
@@ -133,9 +134,8 @@ private:
     QMenu *m_listsMenu;
 
 
-
-    QAction *doneAction;
-    QAction *cancelAction;
+    QAction *m_doneAction;
+    QAction *m_cancelAction;
 
     PumpController *m_pumpController;
 };
