@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,9 +23,11 @@
 
 #include <QWidget>
 #include <QVBoxLayout>
+#include <QHBoxLayout>
 #include <QGridLayout>
 #include <QScrollArea>
 #include <QPushButton>
+#include <QToolButton>
 #include <QLabel>
 #include <QScrollBar>
 #include <QTimer>
@@ -119,6 +121,10 @@ private:
     QTimer *m_getAllCommentsTimer; // To get all comments after a delay
 
     Composer *m_commentComposer;
+    QHBoxLayout *m_topButtonsLayout;
+#ifdef HAVE_KCHARSELECT
+    QToolButton *m_charPickerButton;
+#endif
     QPushButton *m_toolsButton;
     QLabel *m_statusInfoLabel;
     QPushButton *m_commentButton;
