@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,10 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
     this->setAcceptRichText(true);
     this->setTabChangesFocus(true);
 
+#ifdef HAVE_SONNET_SPELLCHECKER
+    m_spellDecorator = new Sonnet::SpellCheckDecorator(this);
+#endif
+
     m_clickToPostString = tr("Click here or press Control+N to post a note...");
 
 
@@ -103,6 +107,15 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
 
     m_toolsMenu->addSeparator();
 
+#ifdef HAVE_SONNET_SPELLCHECKER
+    m_toolsMenu->addAction(QIcon::fromTheme("tools-check-spelling"),
+                           tr("Configure spell checking..."),
+                           this,
+                           SLOT(requestSpellConfigDialog()));
+
+    m_toolsMenu->addSeparator();
+#endif
+
     m_toolsMenu->addAction(QIcon::fromTheme("insert-link"),
                            tr("Make a link"),
                            this,
@@ -134,6 +147,16 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
                               + tr("Text Formatting Options"));
 
 
+#ifdef HAVE_KCHARSELECT
+    m_charPickerButton = new QToolButton(this);
+    m_charPickerButton->setIcon(QIcon::fromTheme("face-smile",
+                                                 QIcon(":/images/button-symbols.png")));
+    m_charPickerButton->setToolTip(tr("Insert symbols"));
+    connect(m_charPickerButton, &QToolButton::clicked,
+            this, &Composer::showCharacterPicker);
+#endif
+
+
     // Extra action for the context menu, paste as plaintext
     m_pastePlaintextAction = new QAction(QIcon::fromTheme("edit-paste"),
                                          tr("Paste Text Without Formatting"),
@@ -275,6 +298,12 @@ QPushButton *Composer::getToolsButton()
     return m_toolsButton;
 }
 
+#ifdef HAVE_KCHARSELECT
+QToolButton *Composer::getCharPickerButton()
+{
+    return m_charPickerButton;
+}
+#endif
 
 /*
  * Enable or disable the Ctrl+Shift+V action to paste without format
@@ -480,10 +509,10 @@ void Composer::insertFromMimeData(const QMimeData *source)
      *
      */
 
-    QString pastedHtml = source->html();
-    QString pastedText = source->text().trimmed();
+    const QString pastedHtml = source->html();
+    const QString pastedText = source->text().trimmed();
 
-    bool sourceHasHtml = source->hasHtml();
+    const bool sourceHasHtml = source->hasHtml();
 
 
     // First, check if it's just a link to an image, to offer embedding it
@@ -496,7 +525,7 @@ void Composer::insertFromMimeData(const QMimeData *source)
          || pastedText.endsWith(".jpeg", Qt::CaseInsensitive)
          || pastedText.endsWith(".gif", Qt::CaseInsensitive))
         {
-            int insertionType= QMessageBox::question(this,
+            const int insertionType = QMessageBox::question(this,
                                             tr("Insert as image?"),
                                             tr("The link you are pasting "
                                                "seems to point to an image.")
@@ -543,9 +572,11 @@ void Composer::insertFromMimeData(const QMimeData *source)
 
         qDebug() << "WORD:" << currentWord;
 
-        if (currentWord == "http" || currentWord == "https"
-         || currentWord == "ftp"  || currentWord == "ftps"
-         || currentWord == "sftp")
+        if (currentWord == QStringLiteral("http")
+         || currentWord == QStringLiteral("https")
+         || currentWord == QStringLiteral("ftp")
+         || currentWord == QStringLiteral("ftps")
+         || currentWord == QStringLiteral("sftp"))
         {
             qDebug() << "Text might be a link";
 
@@ -565,13 +596,13 @@ void Composer::insertFromMimeData(const QMimeData *source)
                     }
                 }
 
-                QString linkFound = cursor.selection().toPlainText();
+                const QString linkFound = cursor.selection().toPlainText();
 
-                if (linkFound.startsWith("http://")
-                 || linkFound.startsWith("https://")
-                 || linkFound.startsWith("ftp://")
-                 || linkFound.startsWith("ftps://")
-                 || linkFound.startsWith("sftp://"))
+                if (linkFound.startsWith(QStringLiteral("http://"))
+                 || linkFound.startsWith(QStringLiteral("https://"))
+                 || linkFound.startsWith(QStringLiteral("ftp://"))
+                 || linkFound.startsWith(QStringLiteral("ftps://"))
+                 || linkFound.startsWith(QStringLiteral("sftp://")))
                 {
                     // Turn current selection into a link to the same as the visible text
                     QTextCharFormat format = cursor.charFormat();
@@ -630,7 +661,7 @@ void Composer::makeBold()
     }
     this->mergeCurrentCharFormat(charFormat);
 
-    this->setFocus(); // give focus back to text editor
+    this->setFocus(); // Give focus back to text editor
 }
 
 
@@ -681,7 +712,7 @@ void Composer::makeStrikethrough()
  */
 void Composer::makeHeader()
 {
-    QString selectedText = this->textCursor().selectedText();
+    const QString selectedText = this->textCursor().selectedText();
 
     if (!selectedText.isEmpty())
     {
@@ -810,6 +841,14 @@ void Composer::makeQuote()
 }
 
 
+/*
+ * Request Sonnet's spellchecking configuration dialog, via GlobalObject
+ *
+ */
+void Composer::requestSpellConfigDialog()
+{
+    m_globalObject->showSpellConfigDialog();
+}
 
 
 /*
@@ -983,6 +1022,19 @@ void Composer::insertSymbol(QAction *action)
 }
 
 
+#ifdef HAVE_KCHARSELECT
+void Composer::showCharacterPicker()
+{
+    // Make focus default to the composer when the character picker is closed
+    this->setFocus();
+
+    m_characterPicker = new CharacterPicker(this);
+    connect(m_characterPicker, &CharacterPicker::characterSelected,
+            this, &Composer::insertHtml);
+    m_characterPicker->show();
+}
+#endif
+
 
 void Composer::pasteAsPlaintext()
 {
