@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,12 +25,13 @@
 #include <QFocusEvent>
 #include <QLabel>
 #include <QPushButton>
+#include <QToolButton>
 #include <QMenu>
 #include <QInputDialog>
 #include <QMessageBox>
 #include <QApplication>
 #include <QClipboard>
-#include <QMimeData> // Needed in Qt5
+#include <QMimeData> // Needed since Qt5
 #include <QCompleter>
 #include <QAbstractItemView> // For QCompleter's popup
 #include <QTableView>
@@ -41,9 +42,17 @@
 
 #include <QDebug>
 
+#ifdef HAVE_SONNET_SPELLCHECKER
+#include <Sonnet/SpellCheckDecorator>
+#endif
+
 #include "globalobject.h"
 #include "mischelpers.h"
 
+#ifdef HAVE_KCHARSELECT
+#include "characterpicker.h"
+#endif
+
 
 class Composer : public QTextEdit
 {
@@ -51,7 +60,7 @@ class Composer : public QTextEdit
 
 public:
     Composer(GlobalObject *globalObject, bool forPublisher,
-             QWidget *parent = 0);
+             QWidget *parent = nullptr);
     ~Composer();
 
     void erase();
@@ -60,6 +69,9 @@ public:
 
     void hideInfoMessage();
     QPushButton *getToolsButton();
+#ifdef HAVE_KCHARSELECT
+    QToolButton *getCharPickerButton();
+#endif
 
     void setPlainPasteEnabled(bool state);
 
@@ -89,12 +101,17 @@ public slots:
     void makeTable();
     void makePreformatted();
     void makeQuote();
+    void requestSpellConfigDialog();
     void makeLink();
     void insertImage();
     void insertLine();
 
     void insertSymbol(QAction *action);
 
+#ifdef HAVE_KCHARSELECT
+    void showCharacterPicker();
+#endif
+
     void pasteAsPlaintext();
 
     void insertCompletedNick(QModelIndex nickData);
@@ -115,6 +132,11 @@ private:
     QMenu *m_toolsMenu;
     QMenu *m_symbolsMenu;
 
+#ifdef HAVE_KCHARSELECT
+    QToolButton *m_charPickerButton;
+    CharacterPicker *m_characterPicker;
+#endif
+
     QAction *m_pastePlaintextAction;
 
     QMenu *m_customContextMenu;
@@ -122,6 +144,9 @@ private:
     QCompleter *m_nickCompleter;
     QTableView *m_popupTableView;
 
+#ifdef HAVE_SONNET_SPELLCHECKER
+    Sonnet::SpellCheckDecorator *m_spellDecorator;
+#endif
 
     QString m_clickToPostString;
     bool m_forPublisher;
