@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -169,7 +169,7 @@ void ContactList::setListContents(QVariantList contactList)
 
     QStringList followingIdStringList;
 
-    foreach (QVariant contact, contactList)
+    foreach (const QVariant contact, contactList)
     {
         QVariantMap contactMap = contact.toMap();
         if (!contactMap.keys().contains(QStringLiteral("id")))
