@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ void FilterChecker::setFilters(QVariantList newFiltersList)
     m_filteredDescription.clear();
 
     // Define new filter values
-    foreach (QVariant filter, newFiltersList)
+    foreach (const QVariant filter, newFiltersList)
     {
         const int filterType = filter.toMap().value(QStringLiteral("type"))
                                              .toInt();
@@ -102,7 +102,7 @@ int FilterChecker::validateActivity(ASActivity *activity)
 
     const QString postTitle = activity->object()->getTitle();
     const QString postContents = activity->object()->getContent();
-    foreach (QStringList contents, m_filteredContent)
+    foreach (const QStringList contents, m_filteredContent)
     {
         if (postContents.contains(contents.first(), Qt::CaseInsensitive)
          || postTitle.contains(contents.first(), Qt::CaseInsensitive))
@@ -117,7 +117,7 @@ int FilterChecker::validateActivity(ASActivity *activity)
 
     const QString activityAuthorId = activity->author()->getId();
     const QString objectAuthorId = activity->object()->author()->getId();
-    foreach (QStringList authorId, m_filteredAuthor)
+    foreach (const QStringList authorId, m_filteredAuthor)
     {
         if (activityAuthorId.contains(authorId.first(), Qt::CaseInsensitive)
          || objectAuthorId.contains(authorId.first(), Qt::CaseInsensitive))
@@ -132,7 +132,7 @@ int FilterChecker::validateActivity(ASActivity *activity)
 
 
     const QString activityGenerator = activity->getGenerator();
-    foreach (QStringList generator, m_filteredGenerator)
+    foreach (const QStringList generator, m_filteredGenerator)
     {
         if (activityGenerator.contains(generator.first(), Qt::CaseInsensitive))
         {
@@ -146,7 +146,7 @@ int FilterChecker::validateActivity(ASActivity *activity)
 
     // Remove links from activity description, so it's easier to write filtering rules
     const QString activityDescription = MiscHelpers::htmlWithoutLinks(activity->getContent());
-    foreach (QStringList description, m_filteredDescription)
+    foreach (const QStringList description, m_filteredDescription)
     {
         if (activityDescription.contains(description.first(), Qt::CaseInsensitive))
         {
