@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -200,7 +200,7 @@ void FilterEditor::loadFilters()
 
     QVariantList filtersList = settings.value("Filters/currentFilters").toList();
 
-    foreach (QVariant filterItem, filtersList)
+    foreach (const QVariant filterItem, filtersList)
     {
         int actionType = filterItem.toMap().value("action").toInt();
         int filterType = filterItem.toMap().value("type").toInt();
