@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -98,7 +98,7 @@ QString FilterMatchesWidget::tagList(QStringList tagsList)
 {
     QString tagListString;
 
-    foreach (QString tag, tagsList)
+    foreach (const QString tag, tagsList)
     {
         // Non-breakable spaces needed in several places
         tagListString.append("<span>&nbsp;&nbsp;"
