@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -161,7 +161,7 @@ void ListsManager::setListsList(QVariantList listsList)
     QVariant listId;
     QVariant listUrl;
 
-    foreach (QVariant list, listsList)
+    foreach (const QVariant list, listsList)
     {
         QVariantMap listMap = list.toMap();
         listName = listMap.value("displayName").toString();
@@ -196,7 +196,7 @@ void ListsManager::setListsList(QVariantList listsList)
     }
 
     // Get list of people in each list
-    foreach (QString url, m_personListsUrlList)
+    foreach (const QString url, m_personListsUrlList)
     {
         m_pumpController->getPersonList(url);
     }
@@ -263,7 +263,7 @@ void ListsManager::setPersonsInList(QVariantList personList, QString listUrl)
     }
 
 
-    foreach (QVariant personVariant, personList)
+    foreach (const QVariant personVariant, personList)
     {
         // FIXME: this should use ASPerson()
         QVariantMap personMap = personVariant.toMap();
