@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,12 +23,23 @@
 #include <QLibraryInfo> // Include needed in some cases
 #include <iostream>
 
+#ifdef HAVE_SONNET_SPELLCHECKER
+ #if __has_include(<KF5/sonnet_version.h>)
+ #include <KF5/sonnet_version.h>
+ #endif
+#endif
+
+#ifdef HAVE_KCHARSELECT
+ #if __has_include(<KF5/kwidgetsaddons_version.h>)
+ #include <KF5/kwidgetsaddons_version.h>
+ #endif
+#endif
+
+
 #include "mainwindow.h"
 
 
 
-
-
 void customMessageHandler(QtMsgType type,
                           const QMessageLogContext &context,
                           const QString &msg)
@@ -48,11 +59,13 @@ int main(int argc, char *argv[])
 {
     QApplication dianaraApp(argc, argv);
     dianaraApp.setApplicationName(QStringLiteral("Dianara"));
-    dianaraApp.setApplicationVersion(QStringLiteral("1.4.2"));
+    dianaraApp.setApplicationVersion(QStringLiteral("1.4.3"));
     dianaraApp.setOrganizationName(QStringLiteral("JanCoding"));
     dianaraApp.setOrganizationDomain(QStringLiteral("jancoding.wordpress.com"));
+    // This is mainly needed for window managers under Wayland
+    dianaraApp.setDesktopFileName(QStringLiteral("org.nongnu.dianara.desktop"));
 
-    std::cout << QString("Dianara v%1 - JanKusanagi 2012-2018\n"
+    std::cout << QString("Dianara v%1 - JanKusanagi 2012-2019\n"
                          "https://jancoding.wordpress.com/dianara\n\n")
                  .arg(dianaraApp.applicationVersion())
                  .toStdString();
@@ -79,6 +92,26 @@ int main(int argc, char *argv[])
                  .arg(qApp->platformName()).toStdString();
     std::cout.flush();
 
+#ifdef HAVE_SONNET_SPELLCHECKER
+    std::cout << "* Built with Sonnet spell checking support";
+ #ifdef SONNET_VERSION_STRING
+    std::cout << ": v" << SONNET_VERSION_STRING << "\n";
+ #else
+    std::cout << ".\n";
+ #endif
+#endif
+
+#ifdef HAVE_KCHARSELECT
+    std::cout << "* Built with KCharSelect symbol selection support";
+ #ifdef KWIDGETSADDONS_VERSION_STRING
+   std::cout << ": v" << KWIDGETSADDONS_VERSION_STRING << "\n";
+ #else
+   std::cout << ".\n";
+ #endif
+#endif
+
+    std::cout << "\n";
+
 
     // To make the mswin version of Dianara distributable as a standalone package
 #ifdef Q_OS_WIN
@@ -97,7 +130,7 @@ int main(int argc, char *argv[])
     // Parse command line parameters
     if (!cmdLine.isEmpty())
     {
-        foreach (QString argument, cmdLine)
+        foreach (const QString argument, cmdLine)
         {
             // Help
             if (argument.startsWith("--help", Qt::CaseInsensitive)
@@ -283,7 +316,6 @@ int main(int argc, char *argv[])
         std::cout << "Unavailable";
     }
 
-
     std::cout << "\n\n";
     std::cout.flush();
 
