@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -55,6 +55,11 @@
 #include "dbusinterface.h"
 #endif
 
+#ifdef HAVE_SONNET_SPELLCHECKER
+#include <Sonnet/Speller>
+#include <Sonnet/ConfigDialog>
+#endif
+
 #include <QDebug>
 
 #include <iostream>
@@ -120,7 +125,7 @@ public:
 
 
 public slots:
-    void updateUserID(QString newUserID);
+    void updateUserId(QString newUserId);
     void updateConfigSettings();
 
     void toggleWidgetsByAuthorization(bool authorized);
@@ -239,7 +244,7 @@ private:
     QMenu *helpMenu;
 
     QMenu *trayContextMenu;
-    QAction *trayTitleSeparatorAction;
+    QAction *m_trayTitleAction;
     QAction *trayShowWindowAction;
 
     QAction *sessionUpdateMainTimeline;
@@ -279,19 +284,19 @@ private:
 
 
     // Info label for the menu
-    QHBoxLayout *menuInfoLayout;
-    QWidget *menuInfoWidget;
-    QLabel *menuInfoLabel;
+    QHBoxLayout *m_menuInfoLayout;
+    QWidget *m_menuInfoWidget;
+    QLabel *m_menuInfoLabel;
 
     // Toolbar
-    QToolBar *mainToolBar;
+    QToolBar *m_mainToolBar;
 
     // Statusbar widgets
-    QToolButton *statusStateButton;
-    QToolButton *statusLogButton;
+    QToolButton *m_statusStateButton;
+    QToolButton *m_statusLogButton;
 
-    QPushButton *statusAccountButton; // Shown when no account is configured
-    bool statusAccountButtonUsed;
+    QPushButton *m_statusAccountButton; // Shown when no account is configured
+    bool m_statusAccountButtonUsed;
     QProgressBar *initializationProgressBar;
 
 
@@ -308,18 +313,18 @@ private:
     QAction *showMentionsFeed;
     QAction *showActionsFeed;
 
-    QWidget *rightSideWidget;
+    QWidget *m_rightSideWidget;
     QVBoxLayout *rightLayout;
     QTabWidget *tabWidget;
-    int tabsPosition;
-    bool tabsMovable;
+    int m_tabsPosition;
+    bool m_tabsMovable;
 
     // User profile widgets
     QPushButton *avatarIconButton;
-    QString avatarURL;
-    QLabel *fullNameLabel;
-    QLabel *userIdLabel;
-    QLabel *userHometownLabel;
+    QString m_avatarUrl;
+    QLabel *m_fullNameLabel;
+    QLabel *m_userIdLabel;
+    QLabel *m_userHometownLabel;
 
 
     QSystemTrayIcon *trayIcon;
@@ -332,21 +337,21 @@ private:
 
     GlobalObject *globalObject;
 
-    AccountDialog *accountDialog;
-    ProfileEditor *profileEditor;
-    ConfigDialog *configDialog;
-    FilterChecker *filterChecker;
-    FilterEditor *filterEditor;
-    LogViewer *logViewer;
-    HelpWidget *helpWidget;
+    AccountDialog *m_accountDialog;
+    ProfileEditor *m_profileEditor;
+    ConfigDialog *m_configDialog;
+    FilterChecker *m_filterChecker;
+    FilterEditor *m_filterEditor;
+    LogViewer *m_logViewer;
+    HelpWidget *m_helpWidget;
     PumpController *pumpController;
-    FDNotifications *fdNotifier;
+    FDNotifications *m_fdNotifications;
 
     MinorFeed *meanwhileFeed;
     MinorFeed *mentionsFeed;
     MinorFeed *actionsFeed;
 
-    BannerNotification *bannerNotification;
+    BannerNotification *m_bannerNotification;
 
     TimeLine *mainTimeline;
     QScrollArea *mainTimelineScrollArea;
@@ -365,8 +370,12 @@ private:
 
     Publisher *publisher;
 
+#ifdef HAVE_SONNET_SPELLCHECKER
+    Sonnet::ConfigDialog *m_spellConfigDialog;
+#endif
+
 #ifdef QT_DBUS_LIB
-    DBusInterface *dbusInterface;
+    DBusInterface *m_dbusInterface;
 #endif
 
 
@@ -393,8 +402,8 @@ private:
     QString oldStatusBarMessage;
     QString previousStatusFeedInfo;
 
-    // user account-related data
-    QString userID;
+    // User account-related data
+    QString m_userId;
 
 };
 
