@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -490,7 +490,7 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
     QList<ASActivity *> activitiesToSync;
     QList<ASActivity *> allProcessedActivities;
 
-    foreach (QVariant activityVariant, activitiesList)
+    foreach (const QVariant activityVariant, activitiesList)
     {
         itemIsNew = false;
 
