@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -275,7 +275,7 @@ const QStringList MiscHelpers::videoExtensions()
 const QString MiscHelpers::fileFilterString(QStringList extensions)
 {
     QString filterString = " (";
-    foreach (QString extension, extensions)
+    foreach (const QString extension, extensions)
     {
         filterString.append(" *." + extension + " ");
     }
@@ -386,7 +386,7 @@ QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWi
         imgSrc = regExp.cap(3);
 
         // Protection: ensure the <img> tag doesn't point to a huge video
-        foreach (QString extension, videoExtensions())
+        foreach (const QString extension, videoExtensions())
         {
             if (imgSrc.endsWith(extension))
             {
