@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ FDNotifications::FDNotifications(QObject *parent) : QObject(parent)
         qDebug() << "Listing D-Bus services...";
         if (busReply.isValid())
         {
-            foreach (QString serviceName, busReply.value())
+            foreach (const QString serviceName, busReply.value())
             {
                 if (serviceName == "org.freedesktop.Notifications")
                 {
