@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -205,7 +205,7 @@ void PeopleWidget::updateAllContactsList(QString listType,
         m_itemModel->clear();
     }
 
-    foreach (QVariant contactVariant, contactsVariantList)
+    foreach (const QVariant contactVariant, contactsVariantList)
     {
         ASPerson *contact = new ASPerson(contactVariant.toMap(), this);
         QStandardItem *item = this->createContactItem(contact);
