@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -154,10 +154,13 @@ Publisher::Publisher(PumpController *pumpController,
             m_titleLineEdit, SLOT(setFocus()));
 
 
+#ifdef HAVE_KCHARSELECT
+    m_charPickerButton = m_composerBox->getCharPickerButton();
+#endif
+
     // Add formatting button exported from Composer
     m_toolsButton = m_composerBox->getToolsButton();
 
-
     // Add menu and submenus to access drafts from the Draft Manager
     m_draftsManager = new DraftsManager(m_globalObject, this);
     connect(m_draftsManager, &DraftsManager::draftSelected,
@@ -313,7 +316,11 @@ Publisher::Publisher(PumpController *pumpController,
     m_titleLayout->addWidget(m_titleLabel,    0);
     m_titleLayout->addSpacing(4);
     m_titleLayout->addWidget(m_titleLineEdit, 2);
-    m_titleLayout->addSpacing(2);
+    m_titleLayout->addSpacing(4);
+#ifdef HAVE_KCHARSELECT
+    m_titleLayout->addWidget(m_charPickerButton, 0);
+    m_titleLayout->addSpacing(4);
+#endif
     m_titleLayout->addWidget(m_toolsButton,   0);
     m_titleLayout->addSpacing(2);
     m_titleLayout->addWidget(m_draftsButton,  0);
@@ -485,12 +492,12 @@ void Publisher::setAudienceFromMap(QVariantMap audienceMap)
     qDebug() << "***** SETTING AUDIENCE FROM DRAFT MAP:";
     qDebug() << audienceMap;
 
-    foreach (QString listType, audienceMap.keys()) // "to", "cc", ATM
+    foreach (const QString listType, audienceMap.keys()) // "to", "cc", ATM
     {
         qDebug() << "LIST:" << listType;
         const QVariantList audienceList = audienceMap.value(listType).toList();
 
-        foreach (QVariant audienceItem, audienceList)
+        foreach (const QVariant audienceItem, audienceList)
         {
             QVariantMap audienceItemMap = audienceItem.toMap();
             qDebug() << "Audience item:" << audienceItemMap;
@@ -766,6 +773,9 @@ void Publisher::toggleWidgetsWhileSending(bool widgetsEnabled)
     m_titleLineEdit->setEnabled(widgetsEnabled);
     m_composerBox->setEnabled(widgetsEnabled);
 
+#ifdef HAVE_KCHARSELECT
+    m_charPickerButton->setEnabled(widgetsEnabled);
+#endif
     m_toolsButton->setEnabled(widgetsEnabled);
     m_draftsButton->setEnabled(widgetsEnabled);
 
@@ -863,6 +873,9 @@ void Publisher::setMinimumMode()
     m_titleLineEdit->hide();
 
     m_toolsButton->hide();
+#ifdef HAVE_KCHARSELECT
+    m_charPickerButton->hide();
+#endif
     m_draftsButton->hide();
 
     // Disable possible scrollbars
@@ -970,6 +983,9 @@ void Publisher::setFullMode()
     m_titleLineEdit->show();
 
     m_toolsButton->show();
+#ifdef HAVE_KCHARSELECT
+    m_charPickerButton->show();
+#endif
     m_draftsButton->show();
 
     m_composerBox->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
