@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
+#include <QToolButton>
 #include <QMenu>
 #include <QFileDialog>
 #include <QMessageBox>
@@ -49,7 +50,7 @@ class Publisher : public QWidget
 public:
     explicit Publisher(PumpController *pumpController,
                        GlobalObject *globalObject,
-                       QWidget *parent = 0);
+                       QWidget *parent = nullptr);
     ~Publisher();
 
     void syncFromConfig();
@@ -140,6 +141,11 @@ private:
     QLabel *m_pictureLabel;
     QProgressBar *m_uploadProgressBar;
 
+
+#ifdef HAVE_KCHARSELECT
+    QToolButton *m_charPickerButton;
+#endif
+
     QPushButton *m_toolsButton;
 
     DraftsManager *m_draftsManager;
