@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
 #endif
 
     // Show date/time when latest stable version was released
-    demoObjectData.insert("published",      "2017-12-30T15:00:00Z");
+    demoObjectData.insert("published",      "2019-12-27T20:00:00Z");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -887,7 +887,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
     QList<Post *> postsInsertedThisTime;
 
     // Fill timeline with new contents
-    foreach (QVariant singlePost, postList)
+    foreach (const QVariant singlePost, postList)
     {
         if (singlePost.type() == QVariant::Map)
         {
